==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Nome"

, "Size"
: "Dimensione"

, "Last Modified"
: "Ultima Modifica"

, "Description"
: "Descrizione"

, "Folder, Folders"
: [
  "Cartella"
 ,"Cartelle"

]
, "File, Files"
: [
  "File"
 ,"File"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "percorso"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Creata da"

, "Creation Time"
: "Data di creazione"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Data Ultima modifica"

, "Last Modified By"
: "Ultima modifica di"

, "Revision"
: "Revisione"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Caricamento fallito"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Tags"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Carica"

, "Open Data Safe"
: ""

, "Folder Up"
: "Cartella superiore"

, "Close Data Safe"
: ""

, "Filemanager"
: "Filemanager"

, "Save locally"
: "Salva in locale"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Tipo"

, "Not yet indexed"
: ""

, "Modified By"
: "Modificato da"

, "Enter description"
: "Inserisci descrizione"

, "Service Unavailable"
: "Servizio non disponibile"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Il Filemanager non è configurato correttamente. Fai riferimento alle Admin FAQ{1} di {0}Tine 2.0 per consigli sulla configurazione o contatta il tuo amministratore"

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vuoi rimpiazzare i seguenti file?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Un elemento con questo nome esiste già!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copia dati .. {0}"

, "Moving data .. {0}"
: "Spostamento dati .. {0}"

, "Please wait"
: "Attendi"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: "Ricerca veloce"

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Crea cartella"

, "New Folder"
: "Nuova Cartella"

, "Please enter the name of the new folder:"
: "Inserisci il nome della nuova cartella"

, "No {0} added"
: "Nessuno/a {0} aggiunto/a"

, "You have to supply a {0} name!"
: "Hai inserito il nome {0}!"

, "Edit Properties"
: "Modifica le proprietà"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Inserisci il nuovo nome di {0}"

, "Not renamed {0}"
: "Non rinominato {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Cancella"

, "Do you really want to delete the following files?"
: "Sei sicuro di voler cancellare i file seguenti?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mie cartelle"

, "Shared folders"
: "Cartelle condivise"

, "Other users folders"
: "Cartelle di altri utenti"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "gestione cartelle condivise"

, "Create new shared folders"
: "Nuova cartella condivisa"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""





, "Folder"
: "Cartella"

, "File"
: "File"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Filemanager/js/Filemanager-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:53+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Usage"
: ""

, "Size"
: "Dimensione"

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "Revision Size"
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Service Unavailable"
: "Servizio non disponibile"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Il Filemanager non è configurato correttamente. Fai riferimento alle Admin FAQ{1} di {0}Tine 2.0 per consigli sulla configurazione o contatta il tuo amministratore"

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Vuoi rimpiazzare i seguenti file?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Un elemento con questo nome esiste già!"

, "Filemanager"
: "Filemanager"

, "Save locally"
: "Salva in locale"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Node Download Links"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "URL"
: ""

, "Created By"
: "Creata da"

, "Creation Time"
: "Data di creazione"

, "Expiration Time"
: ""

, "Password"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Data Ultima modifica"

, "Last Modified By"
: "Ultima modifica di"

, "Folder"
: "Cartella"

, "Total size of all available revisions"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Carica"

, "Open Data Safe"
: ""

, "Folder Up"
: "Cartella superiore"

, "Locking data safe..."
: ""

, "Unlocking data safe..."
: ""

, "Close Data Safe"
: ""

, "Upload Failed"
: "Caricamento fallito"

, "It is not permitted to store files in this folder!"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "path"
: "percorso"

, "Reload"
: ""

, "Create Folder"
: "Crea cartella"

, "New Folder"
: "Nuova Cartella"

, "Please enter the name of the new folder:"
: "Inserisci il nome della nuova cartella"

, "No {0} added"
: "Nessuno/a {0} aggiunto/a"

, "You have to supply a {0} name!"
: "Hai inserito il nome {0}!"

, "Edit Properties"
: "Modifica le proprietà"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Inserisci il nuovo nome di {0}"

, "Not renamed {0}"
: "Non rinominato {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Cancella"

, "Do you really want to delete the following files?"
: "Sei sicuro di voler cancellare i file seguenti?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Name"
: "Nome"

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Revision"
: "Revisione"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Copia dati .. {0}"

, "Moving data .. {0}"
: "Spostamento dati .. {0}"

, "Confirm Changing of Folder Grants"
: ""

, "You are about to move a folder which has own grants. These grants will be lost and the folder will inherit its grants from its new parent folder."
: ""

, "Please wait"
: "Attendi"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "File"
: "File"

, "Public Links"
: ""

, "Type"
: "Tipo"

, "Indexed"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Modificato da"

, "Last Modified"
: "Ultima Modifica"

, "Description"
: "Descrizione"

, "Enter description"
: "Inserisci descrizione"

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "This file has no contents. The Upload has failed or has not yet finished."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Content type"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Mie cartelle"

, "Shared folders"
: "Cartelle condivise"

, "Other users folders"
: "Cartelle di altri utenti"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "manage shared folders"
: "gestione cartelle condivise"

, "Create new shared folders"
: "Nuova cartella condivisa"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""







, "Once a Day"
: ""

, "Download Link"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
